pub struct InvalidRouteModeCombinationError {
pub route_mode: LlmRoute,
pub execution_preference: Option<String>,
pub hint: String,
}Expand description
Typed error returned by the SDK when route + execution_preference
form a rejected combination per the Routing Truth Table in
data-model.md 4.
Fields
route_mode: LlmRouteexecution_preference: Option<String>hint: StringTrait Implementations
Sourceimpl Clone for InvalidRouteModeCombinationError
impl Clone for InvalidRouteModeCombinationError
Sourcefn clone(&self) -> InvalidRouteModeCombinationError
fn clone(&self) -> InvalidRouteModeCombinationError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for InvalidRouteModeCombinationError
Sourceimpl Error for InvalidRouteModeCombinationError
impl Error for InvalidRouteModeCombinationError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<InvalidRouteModeCombinationBody> for InvalidRouteModeCombinationError
impl From<InvalidRouteModeCombinationBody> for InvalidRouteModeCombinationError
Sourcefn from(body: InvalidRouteModeCombinationBody) -> Self
fn from(body: InvalidRouteModeCombinationBody) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for InvalidRouteModeCombinationError
impl PartialEq for InvalidRouteModeCombinationError
Sourcefn eq(&self, other: &InvalidRouteModeCombinationError) -> bool
fn eq(&self, other: &InvalidRouteModeCombinationError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InvalidRouteModeCombinationError