pub struct Capabilities(/* private fields */);Expand description
Capability flags declaring what an app can do
Implementations
Sourceimpl Capabilities
impl Capabilities
Sourcepub const HTTP_HANDLER: Capabilities
pub const HTTP_HANDLER: Capabilities
App can handle proxied HTTP requests
Sourcepub const EVENT_LISTENER: Capabilities
pub const EVENT_LISTENER: Capabilities
App can receive domain events
Sourcepub const FILESYSTEM_READ: Capabilities
pub const FILESYSTEM_READ: Capabilities
App can read files from allowed paths
Sourcepub const FILESYSTEM_WRITE: Capabilities
pub const FILESYSTEM_WRITE: Capabilities
App can write files to allowed paths
Sourcepub const NETWORK_OUTBOUND: Capabilities
pub const NETWORK_OUTBOUND: Capabilities
App can make outbound network requests
Sourcepub const SYSTEM_INFO: Capabilities
pub const SYSTEM_INFO: Capabilities
App can read system information (hostname, etc.)
Sourcepub const CAPABILITY_PROVIDER: Capabilities
pub const CAPABILITY_PROVIDER: Capabilities
App provides service capabilities to other apps
Sourceimpl Capabilities
impl Capabilities
Sourcepub const fn empty() -> Capabilities
pub const fn empty() -> Capabilities
Get a flags value with all bits unset.
Sourcepub const fn all() -> Capabilities
pub const fn all() -> Capabilities
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Capabilities>
pub const fn from_bits(bits: u32) -> Option<Capabilities>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Capabilities
pub const fn from_bits_truncate(bits: u32) -> Capabilities
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Capabilities
pub const fn from_bits_retain(bits: u32) -> Capabilities
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Capabilities>
pub fn from_name(name: &str) -> Option<Capabilities>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Capabilities) -> bool
pub const fn intersects(&self, other: Capabilities) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Capabilities) -> bool
pub const fn contains(&self, other: Capabilities) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: Capabilities)
pub fn insert(&mut self, other: Capabilities)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: Capabilities)
pub fn remove(&mut self, other: Capabilities)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Capabilities)
pub fn toggle(&mut self, other: Capabilities)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Capabilities, value: bool)
pub fn set(&mut self, other: Capabilities, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Capabilities) -> Capabilities
pub const fn intersection(self, other: Capabilities) -> Capabilities
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Capabilities) -> Capabilities
pub const fn union(self, other: Capabilities) -> Capabilities
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Capabilities) -> Capabilities
pub const fn difference(self, other: Capabilities) -> Capabilities
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Capabilities) -> Capabilities
pub const fn symmetric_difference(self, other: Capabilities) -> Capabilities
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Capabilities
pub const fn complement(self) -> Capabilities
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Capabilities
impl Capabilities
Sourcepub const fn iter(&self) -> Iter<Capabilities>
pub const fn iter(&self) -> Iter<Capabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Capabilities>
pub const fn iter_names(&self) -> IterNames<Capabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Capabilities
impl Capabilities
Sourcepub fn to_string_list(&self) -> Vec<String>
pub fn to_string_list(&self) -> Vec<String>
Convert to a list of capability strings for API responses
Sourcepub fn from_bits_safe(bits: u32) -> Capabilities
pub fn from_bits_safe(bits: u32) -> Capabilities
Parse from integer (used for database storage)
Sourcepub fn from_string(s: &str) -> Option<Capabilities>
pub fn from_string(s: &str) -> Option<Capabilities>
Convert capability string to Capabilities flag
Sourcepub fn all_capability_names() -> &'static [&'static str]
pub fn all_capability_names() -> &'static [&'static str]
Get all capability names as static strings