pub fn get_storage(key: &str) -> Option<String>Expand description
Get a storage value by key, scoped to this app.
See set_storage for scoping semantics. Returns None if the key
is not found or the context is not available.
pub fn get_storage(key: &str) -> Option<String>Get a storage value by key, scoped to this app.
See set_storage for scoping semantics. Returns None if the key
is not found or the context is not available.